# abby

> AB testing for Python

Abby is a python library package for A/B testing for human. Abby aims to make A/B testing easy and accessible to anyone.

[![PyPI Version][pypi-image]][pypi-url]
[![Build Status][build-image]][build-url]

<!-- Badges -->

[pypi-image]: https://img.shields.io/pypi/v/abby
[pypi-url]: https://pypi.org/project/abby/
[build-image]: https://github.com/farhanreynaldo/abby/actions/workflows/test.yml/badge.svg
[build-url]: https://github.com/farhanreynaldo/abby/actions/workflows/test.yml
